@@ -4,18 +4,17 @@ from pysyte.types.paths import path
 
 class PathParser(ArgumentsParser):
     """Handle positional args as paths"""
+
     def __init__(self, argparser, paths_arg=None):
         super().__init__(argparser)
-        self.paths_arg = paths_arg if paths_arg else 'paths'
+        self.paths_arg = paths_arg if paths_arg else "paths"
         super().positionals(self.paths_arg)
 
-
     def post_parser(self, arguments):
         strings = arguments.get_arg(self.paths_arg)
         paths = [path(_) for _ in strings]
-        existing = [_ for _ in paths if _]
         arguments.set_arg(self.paths_arg, [_ for _ in paths if _])
-        arguments.set_arg(f'not_{self.paths_arg}', [_ for _ in paths if not _])
+        arguments.set_arg(f"not_{self.paths_arg}", [_ for _ in paths if not _])
         return arguments
 
 
