@@ -4,6 +4,7 @@ import yaml
 
 from pysyte.types.dictionaries import NameSpaces
 
+
 class Config(NameSpaces):
     def __init__(self, data):
         super().__init__(data)
@@ -16,5 +17,5 @@ def load(path_to_config):
 
 
 def dump(data, path_to_config):
-    with path_to_config.open('w') as stream:
+    with path_to_config.open("w") as stream:
         yaml.safe_dump(data, stream, explicit_start=True)
