@@ -6,10 +6,10 @@ class NoTerminalAvailable(NotImplementedError):
 
 
 def _tput(tput_command):
-    command = f'tput {tput_command}'
+    command = f"tput {tput_command}"
     status, output = getstatusoutput(command)
     if status:
-        if 'No value for $TERM' in output:
+        if "No value for $TERM" in output:
             raise NoTerminalAvailable(output)
         raise NotImplementedError(output)
     if not output:
@@ -21,8 +21,8 @@ def _tput(tput_command):
 
 
 def screen_width():
-    return _tput('cols')
+    return _tput("cols")
 
 
 def screen_height():
-    return _tput('lines')
+    return _tput("lines")
